tuplettools.remove_trivial_tuplets_in_expr
==========================================

.. autofunction:: abjad.tools.tuplettools.remove_trivial_tuplets_in_expr.remove_trivial_tuplets_in_expr
   :noindex:
